/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Mandatory      *
* Minimum Penalties for Identity Theft Offenders in the Federal Criminal Justice System  *
* report file and create a SAS dataset.                                                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\ussc_id_mm_report_public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = ussc_id_mm_report_public ;

DATA library.&dataset ;
INFILE datafile LRECL=671;
INPUT
   SENSPLT0  1-6            USSCIDN  7-13            AGE  14-15            
   AMENDYR  16-19           CIRCDIST  20-21          MONRACE  22           
   MONSEX  23               NEWCIT  24               NEWRACE  25           
   SENTIMP  26              SOURCES  27              XCRHISSR  28          
   YEARS  29                GLMIN  30-33             IDMIN  34-36          
   STATMIN  37-39           SMIN1  40-42             SMIN2  43-45          
   SMIN3  46-48             SMIN4  49-51             SMIN5  52-54          
   SMIN6  55-57             SMIN7  58-60             SMIN8  61-63          
   SMIN9  64-65             SMIN10  66-68            SMIN11  69-70         
   SMIN12  71-73            SMIN13  74-75            SMIN14  76-77         
   SMIN15  78-79            SMIN16  80-81            SMIN17  82-83         
   SMIN18  84-85            SMIN19  86-87            SMIN20  88-89         
   SMIN21  90-92            SMIN22  93-94            SMIN23  95-96         
   SMIN24  97-98            SMIN25  99-100           SMIN26  101-102       
   SMIN27  103-104          SMIN28  105-107          SMIN29  108-109       
   SMIN30  110-111          SMIN31  112-113          SMIN32  114-115       
   SMIN33  116-117          SMIN34  118-119          SMIN35  120-121       
   SMIN36  122-123          SMIN37  124-125          SMIN38  126-127       
   SMIN39  128-129          SMIN40  130-131          SMIN41  132-133       
   SMIN42  134-135          SMIN43  136-137          SMIN44  138-139       
   SMIN45  140-141          SMIN46  142-143          SMIN47  144-145       
   SMIN48  146-147          SMIN49  148-149          SMIN50  150-151       
   SMIN51  152-153          SMIN52  154-155          SMIN53  156-157       
   SMIN54  158-159          SMIN55  160-161          SMIN56  162-163       
   SMIN57  164-165          SMIN58  166-167          SMIN59  168-169       
   SMIN60  170-171          SMIN61  172-173          SMIN62  174-175       
   SMIN63  176-177          SMIN64  178-179          SMIN65  180-181       
   SMIN66  182-183          SMIN67  184-185          SMIN68  186-187       
   SMIN69  188-189          SMIN70  190-191          SMIN71  192-193       
   SMIN72  194-195          SMIN73  196-197          SMIN74  198-199       
   SMIN75  200-201          SMIN76  202-203          SMIN77  204           
   SMIN78  205              SMIN79  206              SMIN80  207-208       
   SMIN81  209              SMIN82  210              SMIN83  211           
   SMIN84  212              SMIN85  213              SMIN86  214           
   SMIN87  215              SMIN88  216              SMIN89  217           
   SMIN90  218              SMIN91  219              SMIN92  220           
   SMIN93  221              SMIN94  222              SMIN95  223           
   SMIN96  224              SMIN97  225              SMIN98  226           
   SMIN99  227              SMIN100  228             SMIN101  229-230      
   SMIN102  231             SMIN103  232             SMIN104  233          
   SMIN105  234             SMIN106  235             SMIN107  236-237      
   SMIN108  238             SMIN109  239             SMIN110  240          
   SMIN111  241             SMIN112  242             SMIN113  243          
   SMIN114  244             SMIN115  245             SMIN116  246          
   SMIN117  247             SMIN118  248             SMIN119  249          
   SMIN120  250             SMIN121  251             SMIN122  252          
   SMIN123  253             SMIN124  254             SMIN125  255          
   SMIN126  256             SMIN127  257             SMIN128  258          
   SMIN129  259             SMIN130  260             SMIN131  261          
   SMIN132  262             SMIN133  263             SMIN134  264          
   SMIN135  265             SMIN136  266             SMIN137  267          
   SMIN138  268             SMIN139  269             SMIN140  270          
   SMIN141  271             SMIN142  272             SMIN143  273          
   SMIN144  274             SMIN145  275             SMIN146  276          
   SMIN147  277             SMIN148  278             SMIN149  279          
   SMIN150  280             SMIN151  281             SMIN152  282          
   SMIN153  283             SMIN154  284             SMIN155  285          
   SMIN156  286             SMIN157  287             SMIN158  288          
   SMIN159  289             SMIN160  290             SMIN161  291          
   SMIN162  292             SMIN163  293             SMIN164  294          
   SMIN165  295             SMIN166  296             SMIN167  297          
   SMIN168  298             SMIN169  299             SMIN170  300          
   SMIN171  301             SMIN172  302             SMIN173  303          
   SMIN174  304             SMIN175  305             SMIN176  306          
   SMIN177  307             SMIN178  308             SMIN179  309          
   SMIN180  310             SMIN181  311             SMIN182  312          
   SMIN183  313             SMIN184  314             SMIN185  315          
   SMIN186  316             SMIN187  317             SMIN188  318          
   SMIN189  319             SMIN190  320             SMIN191  321          
   SMIN192  322             SMIN193  323             SMIN194  324          
   SMIN195  325             SMIN196  326-327         SMIN197  328          
   SMIN198  329             SMIN199  330             SMIN200  331          
   SMIN201  332             SMIN202  333             SMIN203  334          
   SMIN204  335             SMIN205  336             SMIN206  337          
   SMIN207  338             SMIN208  339             SMIN209  340          
   SMIN210  341             SMIN211  342             SMIN212  343          
   SMIN213  344             SMIN214  345             SMIN215  346          
   SMIN216  347             SMIN217  348             SMIN218  349          
   SMIN219  350             SMIN220  351             SMIN221  352          
   SMIN222  353             SMIN223  354             SMIN224  355          
   SMIN225  356             SMIN226  357             SMIN227  358          
   SMIN228  359             SMIN229  360             SMIN230  361          
   SMIN231  362             SMIN232  363             SMIN233  364          
   SMIN234  365             SMIN235  366             SMIN236  367          
   SMIN237  368             SMIN238  369             SMIN239  370          
   SMIN240  371             SMIN241  372             SMIN242  373          
   SMIN243  374             SMIN244  375             SMIN245  376          
   SMIN246  377             SMIN247  378             ABUSHI  379           
   ADJ_BHI  380-381         ADJ_CHI  382-383         ADJ_DHI  384          
   ADJ_EHI  385-386         ADJ_FHI  387             ADJ_GHI  388          
   ADJ_HHI  389-390         ADJ_IHI  391             ADJ_JHI  392-393      
   ADJ_KHI  394             ADJ_LHI  395-396         ADJ_MHI  397          
   ADJ_NHI  398             ADJ_OHI  399             ADJ_PHI  400          
   AGGROLHI  401            BASEHI  402-403          MITROLHI  404-405     
   OBSTRCHI  406            GDLINEHI $ 407-412       LOSSHI  413-422       
   BOOKERCD  423-424        ONLY1028A  425           IS1028A  426          
   BOOKER2  427             FY  428-431              ADJ_QHI  432-433      
   MONCIRC  434-435         SMIN248  436             SMIN249  437          
   SMIN250  438             SMIN251  439             SMIN252  440          
   SMIN253  441             SMIN254  442             SMIN255  443          
   SMIN256  444             SMIN257  445             SMIN258  446          
   SMIN259  447             SMIN260  448             SMIN261  449          
   SMIN262  450             SMIN263  451             SMIN264  452          
   SMIN265  453             SMIN266  454             SMIN267  455          
   SMIN268  456             SMIN269  457             SMIN270  458          
   SMIN271  459             SMIN272  460             SMIN273  461          
   SMIN274  462             SMIN275  463             SMIN276  464          
   SMIN277  465             SMIN278  466             SMIN279  467          
   SMIN280  468             SMIN281  469             SMIN282  470          
   SMIN283  471             SMIN284  472             SMIN285  473          
   SMIN286  474             SMIN287  475             SMIN288  476          
   SMIN289  477             SMIN290  478             SMIN291  479          
   SMIN292  480             SMIN293  481             SMIN294  482          
   SMIN295  483             SMIN296  484             SMIN297  485          
   SMIN298  486             SMIN299  487             SMIN300  488          
   SMIN301  489             SMIN302  490             SMIN303  491          
   SMIN304  492             SMIN305  493             SMIN306  494          
   SMIN307  495             SMIN308  496             SMIN309  497          
   SMIN310  498             SMIN311  499             SMIN312  500          
   SMIN313  501             SMIN314  502             SMIN315  503          
   SMIN316  504             SMIN317  505             SMIN318  506          
   SMIN319  507             SMIN320  508             SMIN321  509          
   SMIN322  510             SMIN323  511             SMIN324  512          
   SMIN325  513             SMIN326  514             SMIN327  515          
   SMIN328  516             SMIN329  517             SMIN330  518          
   SMIN331  519             SMIN332  520             SMIN333  521          
   SMIN334  522             SMIN335  523             SMIN336  524          
   SMIN337  525             SMIN338  526             SMIN339  527          
   SMIN340  528             SMIN341  529             SMIN342  530          
   SMIN343  531             SMIN344  532             SMIN345  533          
   SMIN346  534             SMIN347  535             SMIN348  536          
   SMIN349  537             SMIN350  538             SMIN351  539          
   SMIN352  540             SMIN353  541             SMIN354  542          
   SMIN355  543             SMIN356  544             SMIN357  545          
   SMIN358  546             SMIN359  547             SMIN360  548          
   SMIN361  549             SMIN362  550             SMIN363  551          
   SMIN364  552             SMIN365  553             SMIN366  554          
   SMIN367  555             SMIN368  556             SMIN369  557          
   SMIN370  558             SMIN371  559             SMIN372  560          
   SMIN373  561             SMIN374  562             SMIN375  563          
   SMIN376  564             SMIN377  565             SMIN378  566          
   SMIN379  567             SMIN380  568             SMIN381  569          
   SMIN382  570             SMIN383  571             SMIN384  572          
   SMIN385  573             SMIN386  574             SMIN387  575          
   SMIN388  576             SMIN389  577             SMIN390  578          
   SMIN391  579             SMIN392  580             SMIN393  581          
   SMIN394  582             SMIN395  583             ADJ_RHI  584-585      
   ADJ_SHI  586             ADJ_THI  587             NEWCNVTN  588         
   NOCOUNTS_AGGID  589-590   MULTIPLE_AGGID  591      IDMM_RELIEF  592      
   CH2_COUNT_YN  593        CH2_GDLINE $ 594-598     ECON_TYPE  599-600    
   ECON_TYPE_OTHER  601-602   MULT_CONSEC_YN  603      MULT_CONSEC_24MO  604 
   MULT_TEXT $ 605-653      CH2_COUNT1 $ 654-659     CH2_COUNT2 $ 660-665  
   CH2_COUNT3 $ 666-671   ;                       

LENGTH
   USSCIDN 6                AGE 3                    AMENDYR 4             
   CIRCDIST 3               MONRACE 3                MONSEX 3              
   NEWCIT 3                 NEWRACE 3                SENTIMP 3             
   SOURCES 3                XCRHISSR 3               YEARS 3               
   GLMIN 4                  IDMIN 4                  STATMIN 4             
   SMIN1 4                  SMIN2 4                  SMIN3 4               
   SMIN4 4                  SMIN5 4                  SMIN6 4               
   SMIN7 4                  SMIN8 4                  SMIN9 3               
   SMIN10 4                 SMIN11 3                 SMIN12 4              
   SMIN13 3                 SMIN14 3                 SMIN15 3              
   SMIN16 3                 SMIN17 3                 SMIN18 3              
   SMIN19 3                 SMIN20 3                 SMIN21 4              
   SMIN22 3                 SMIN23 3                 SMIN24 3              
   SMIN25 3                 SMIN26 3                 SMIN27 3              
   SMIN28 4                 SMIN29 3                 SMIN30 3              
   SMIN31 3                 SMIN32 3                 SMIN33 3              
   SMIN34 3                 SMIN35 3                 SMIN36 3              
   SMIN37 3                 SMIN38 3                 SMIN39 3              
   SMIN40 3                 SMIN41 3                 SMIN42 3              
   SMIN43 3                 SMIN44 3                 SMIN45 3              
   SMIN46 3                 SMIN47 3                 SMIN48 3              
   SMIN49 3                 SMIN50 3                 SMIN51 3              
   SMIN52 3                 SMIN53 3                 SMIN54 3              
   SMIN55 3                 SMIN56 3                 SMIN57 3              
   SMIN58 3                 SMIN59 3                 SMIN60 3              
   SMIN61 3                 SMIN62 3                 SMIN63 3              
   SMIN64 3                 SMIN65 3                 SMIN66 3              
   SMIN67 3                 SMIN68 3                 SMIN69 3              
   SMIN70 3                 SMIN71 3                 SMIN72 3              
   SMIN73 3                 SMIN74 3                 SMIN75 3              
   SMIN76 3                 SMIN77 3                 SMIN78 3              
   SMIN79 3                 SMIN80 3                 SMIN81 3              
   SMIN82 3                 SMIN83 3                 SMIN84 3              
   SMIN85 3                 SMIN86 3                 SMIN87 3              
   SMIN88 3                 SMIN89 3                 SMIN90 3              
   SMIN91 3                 SMIN92 3                 SMIN93 3              
   SMIN94 3                 SMIN95 3                 SMIN96 3              
   SMIN97 3                 SMIN98 3                 SMIN99 3              
   SMIN100 3                SMIN101 3                SMIN102 3             
   SMIN103 3                SMIN104 3                SMIN105 3             
   SMIN106 3                SMIN107 3                SMIN108 3             
   SMIN109 3                SMIN110 3                SMIN111 3             
   SMIN112 3                SMIN113 3                SMIN114 3             
   SMIN115 3                SMIN116 3                SMIN117 3             
   SMIN118 3                SMIN119 3                SMIN120 3             
   SMIN121 3                SMIN122 3                SMIN123 3             
   SMIN124 3                SMIN125 3                SMIN126 3             
   SMIN127 3                SMIN128 3                SMIN129 3             
   SMIN130 3                SMIN131 3                SMIN132 3             
   SMIN133 3                SMIN134 3                SMIN135 3             
   SMIN136 3                SMIN137 3                SMIN138 3             
   SMIN139 3                SMIN140 3                SMIN141 3             
   SMIN142 3                SMIN143 3                SMIN144 3             
   SMIN145 3                SMIN146 3                SMIN147 3             
   SMIN148 3                SMIN149 3                SMIN150 3             
   SMIN151 3                SMIN152 3                SMIN153 3             
   SMIN154 3                SMIN155 3                SMIN156 3             
   SMIN157 3                SMIN158 3                SMIN159 3             
   SMIN160 3                SMIN161 3                SMIN162 3             
   SMIN163 3                SMIN164 3                SMIN165 3             
   SMIN166 3                SMIN167 3                SMIN168 3             
   SMIN169 3                SMIN170 3                SMIN171 3             
   SMIN172 3                SMIN173 3                SMIN174 3             
   SMIN175 3                SMIN176 3                SMIN177 3             
   SMIN178 3                SMIN179 3                SMIN180 3             
   SMIN181 3                SMIN182 3                SMIN183 3             
   SMIN184 3                SMIN185 3                SMIN186 3             
   SMIN187 3                SMIN188 3                SMIN189 3             
   SMIN190 3                SMIN191 3                SMIN192 3             
   SMIN193 3                SMIN194 3                SMIN195 3             
   SMIN196 3                SMIN197 3                SMIN198 3             
   SMIN199 3                SMIN200 3                SMIN201 3             
   SMIN202 3                SMIN203 3                SMIN204 3             
   SMIN205 3                SMIN206 3                SMIN207 3             
   SMIN208 3                SMIN209 3                SMIN210 3             
   SMIN211 3                SMIN212 3                SMIN213 3             
   SMIN214 3                SMIN215 3                SMIN216 3             
   SMIN217 3                SMIN218 3                SMIN219 3             
   SMIN220 3                SMIN221 3                SMIN222 3             
   SMIN223 3                SMIN224 3                SMIN225 3             
   SMIN226 3                SMIN227 3                SMIN228 3             
   SMIN229 3                SMIN230 3                SMIN231 3             
   SMIN232 3                SMIN233 3                SMIN234 3             
   SMIN235 3                SMIN236 3                SMIN237 3             
   SMIN238 3                SMIN239 3                SMIN240 3             
   SMIN241 3                SMIN242 3                SMIN243 3             
   SMIN244 3                SMIN245 3                SMIN246 3             
   SMIN247 3                ABUSHI 3                 ADJ_BHI 3             
   ADJ_CHI 3                ADJ_DHI 3                ADJ_EHI 3             
   ADJ_FHI 3                ADJ_GHI 3                ADJ_HHI 3             
   ADJ_IHI 3                ADJ_JHI 3                ADJ_KHI 3             
   ADJ_LHI 3                ADJ_MHI 3                ADJ_NHI 3             
   ADJ_OHI 3                ADJ_PHI 3                AGGROLHI 3            
   BASEHI 3                 MITROLHI 3               OBSTRCHI 3            
   BOOKERCD 3               ONLY1028A 3              IS1028A 3             
   BOOKER2 3                FY 4                     ADJ_QHI 3             
   MONCIRC 3                SMIN248 3                SMIN249 3             
   SMIN250 3                SMIN251 3                SMIN252 3             
   SMIN253 3                SMIN254 3                SMIN255 3             
   SMIN256 3                SMIN257 3                SMIN258 3             
   SMIN259 3                SMIN260 3                SMIN261 3             
   SMIN262 3                SMIN263 3                SMIN264 3             
   SMIN265 3                SMIN266 3                SMIN267 3             
   SMIN268 3                SMIN269 3                SMIN270 3             
   SMIN271 3                SMIN272 3                SMIN273 3             
   SMIN274 3                SMIN275 3                SMIN276 3             
   SMIN277 3                SMIN278 3                SMIN279 3             
   SMIN280 3                SMIN281 3                SMIN282 3             
   SMIN283 3                SMIN284 3                SMIN285 3             
   SMIN286 3                SMIN287 3                SMIN288 3             
   SMIN289 3                SMIN290 3                SMIN291 3             
   SMIN292 3                SMIN293 3                SMIN294 3             
   SMIN295 3                SMIN296 3                SMIN297 3             
   SMIN298 3                SMIN299 3                SMIN300 3             
   SMIN301 3                SMIN302 3                SMIN303 3             
   SMIN304 3                SMIN305 3                SMIN306 3             
   SMIN307 3                SMIN308 3                SMIN309 3             
   SMIN310 3                SMIN311 3                SMIN312 3             
   SMIN313 3                SMIN314 3                SMIN315 3             
   SMIN316 3                SMIN317 3                SMIN318 3             
   SMIN319 3                SMIN320 3                SMIN321 3             
   SMIN322 3                SMIN323 3                SMIN324 3             
   SMIN325 3                SMIN326 3                SMIN327 3             
   SMIN328 3                SMIN329 3                SMIN330 3             
   SMIN331 3                SMIN332 3                SMIN333 3             
   SMIN334 3                SMIN335 3                SMIN336 3             
   SMIN337 3                SMIN338 3                SMIN339 3             
   SMIN340 3                SMIN341 3                SMIN342 3             
   SMIN343 3                SMIN344 3                SMIN345 3             
   SMIN346 3                SMIN347 3                SMIN348 3             
   SMIN349 3                SMIN350 3                SMIN351 3             
   SMIN352 3                SMIN353 3                SMIN354 3             
   SMIN355 3                SMIN356 3                SMIN357 3             
   SMIN358 3                SMIN359 3                SMIN360 3             
   SMIN361 3                SMIN362 3                SMIN363 3             
   SMIN364 3                SMIN365 3                SMIN366 3             
   SMIN367 3                SMIN368 3                SMIN369 3             
   SMIN370 3                SMIN371 3                SMIN372 3             
   SMIN373 3                SMIN374 3                SMIN375 3             
   SMIN376 3                SMIN377 3                SMIN378 3             
   SMIN379 3                SMIN380 3                SMIN381 3             
   SMIN382 3                SMIN383 3                SMIN384 3             
   SMIN385 3                SMIN386 3                SMIN387 3             
   SMIN388 3                SMIN389 3                SMIN390 3             
   SMIN391 3                SMIN392 3                SMIN393 3             
   SMIN394 3                SMIN395 3                ADJ_RHI 3             
   ADJ_SHI 3                ADJ_THI 3                NEWCNVTN 3            
   NOCOUNTS_AGGID 3         MULTIPLE_AGGID 3         IDMM_RELIEF 3         
   CH2_COUNT_YN 3           ECON_TYPE 3              ECON_TYPE_OTHER 3     
   MULT_CONSEC_YN 3         MULT_CONSEC_24MO 3 ;



RUN ;
